==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_val-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="val-ES" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Crea un full de càlcul</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Crea un full de càlcul nouj</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Alinea a la part inferior</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Alineació a la part inferior del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Alinea al centre</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Alineació al centre del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Alinea a l'esquerra</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Alineació a l'equerra del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Alinea a la dreta</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Alineació a la dreta del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Alinea a la part superior</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Alineació a la part superior del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Alinea al centre verticalment</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exporta el full de càlcul</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exporta el full de càlcul a CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importa el full de càlcul</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importa el fitxer CSV a un full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Fusiona les cel·les</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Fusiona les cel·les seleccionades en el full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Estableix l'àlies</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Estableix l'àlies per a les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Divideix la cel·la</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Divideix les cel·les fusionades anteriorment en el full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Text en negreta</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Estableix el text en negreta en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Text en cursiva</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Estableix el text en cursiva en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Text subratllat</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Propietats de cel·la</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Color</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Text</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fons</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Alineació</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Esquerra</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Centre</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dreta</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Planta</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Inferior</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>E&amp;stil</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Negreta</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Cursiva</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Subratllat</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Unitat de mesura</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Cadena d'unitats</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>À&amp;lies</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Àlies per a aquesta cel·la</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Tot (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importa el fitxer</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exporta el fitxer</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Contingut de la cel·la</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Mostra el full de càlcul</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Estableix el color de primer pla de la cel·la(es)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Estableix el color de primer pla de la cel·la(es) del full de càlcul</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Estableix el color de fons de la cel·la(es)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Estableix el color de fons de la cel·la(es) del full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Negre</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Blanc</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Roig</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Roig fosc</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Verd</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Verd fosc</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Blau</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Blau fosc</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cian</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Cian fosc</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Magenta fosc</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Groc</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Groc fosc</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Gris</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Gris fosc</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Gris clar</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Personalitzat</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Contingut</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Sense nom</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Insereix files</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Suprimeix files</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Insereix columnes</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Suprimeix columnes</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Propietats...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_val-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="val-ES" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Crea un full de càlcul</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Crea un full de càlcul nouj</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Alinea a la part inferior</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Alineació a la part inferior del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Alinea al centre</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Alineació al centre del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Alinea a l'esquerra</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Alineació a l'equerra del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Alinea a la dreta</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Alineació a la dreta del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Alinea a la part superior</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Alineació a la part superior del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Alinea al centre verticalment</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Alineació vertical i centrada dels continguts de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exporta el full de càlcul</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exporta el full de càlcul a CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importa el full de càlcul</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importa el fitxer CSV a un full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Fusiona les cel·les</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>Fusiona les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Estableix l'àlies</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Estableix l'àlies per a les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Divideix la cel·la</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>Divideix les cel·les prèviament fusionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Text en negreta</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>Estableix el text en negreta en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Text en cursiva</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>Estableix el text en cursiva en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Text subratllat</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Subratlla el text en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Color personalitzat</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Fusiona les cel·les</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Divideix la cel·la</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation type="unfinished">Left-align cell</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation type="unfinished">Center cell</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation type="unfinished">Right-align cell</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation type="unfinished">Top-align cell</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation type="unfinished">Bottom-align cell</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation type="unfinished">Vertically center cells</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation type="unfinished">Set bold text</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation type="unfinished">Set italic text</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation type="unfinished">Set underline text</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation type="unfinished">Create Spreadsheet</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation type="unfinished">Set cell properties</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation type="unfinished">Edit cell</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Insereix files</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Suprimeix files</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Insereix columnes</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation type="unfinished">Clear cell(s)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation type="unfinished">Set foreground color</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation type="unfinished">Set background color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Propietats de cel·la</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Color</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Text</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fons</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Alineació</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Horitzontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Esquerra</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Centre</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dreta</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Planta</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Inferior</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>E&amp;stil</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Negreta</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Cursiva</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Subratllat</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Unitat de mesura</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Cadena d'unitats</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>À&amp;lies</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Àlies per a aquesta cel·la</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Tot (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importa el fitxer</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exporta el fitxer</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Mostra el full de càlcul</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Estableix el color de primer pla de la cel·la(es)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Estableix el color de primer pla de la cel·la(es) del full de càlcul</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Estableix el color de fons de la cel·la(es)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Estableix el color de fons de la cel·la(es) del full de càlcul</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>El full de càlcul no admet la selecció de rang en apegar. Seleccioneu només una cel·la.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>S'ha produït un error en copiar i apegar</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation type="unfinished">Alias contains invalid characters!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Negre</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Blanc</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Roig</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Roig fosc</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Verd</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Verd fosc</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Blau</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Blau fosc</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cian</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Cian fosc</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Magenta fosc</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Groc</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Groc fosc</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Gris</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Gris fosc</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Gris clar</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>Color personalitzat</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation type="unfinished">&amp;Content:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation type="unfinished">&amp;Alias:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Sense nom</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Insereix files</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Suprimeix files</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Insereix columnes</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Suprimeix columnes</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Propietats...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
  </context>
</TS>
